@@ -228,6 +228,9 @@ class RequestHandler(tornado.web.RequestHandler):
         # ez-hack
 
         self.debug = self.application.settings.get('debug', False)
+        self.css_debug = self.application.settings.get('css_debug', False)
+        self.js_debug = self.application.settings.get('js_debug', False)
+
 
         self.cdn = self.application.settings.get('cdn', '')
         self.browser_type = self.application.settings.get('browser_default_type', 'mobile')
@@ -259,7 +262,9 @@ class RequestHandler(tornado.web.RequestHandler):
         self.api_messages = self.application.settings.get('api_messages', {})
 
         self.project_version = self.application.settings.get('version', None)
-        self.project_name = self.application.settings.get('project', None)
+        self.project_name = self.application.settings.get('project', {}).get('name','')
+        self.project_desc = self.application.settings.get('project', {}).get('desc','')
+        self.project_keywords = self.application.settings.get('project', {}).get('keywords','')
 
         self.css_version = self.application.settings.get('css_version', str(int(time())))
         self.js_version = self.application.settings.get('js_version', str(int(time())))
@@ -325,11 +330,15 @@ class RequestHandler(tornado.web.RequestHandler):
             'debug': int(self.debug),
             'project_version': self.project_version,
             'project_name': self.project_name,
+            'project_desc':self.project_desc,
+            'project_keywords':self.project_keywords,
             'author': self.author,
             'copyright':self.copyright,
             'copyright_text':self.copyright_text,
             'js_version':self.js_version,
-            'css_version':self.css_version
+            'css_version':self.css_version,
+            'js_debug':self.js_debug,
+            'css_debug':self.css_debug
         })
 
         return namespace
